@@ -104,7 +104,7 @@ tpr2 <- c(1.05, 1.1, 1.2, 1.3)
 ppr2 <- c(0.5, 1.0, 1.5, 2, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0, 5.5, 6.0, 6.5) 
 
 sk_dak_2 <- createTidyFromMatrix(ppr2, tpr2, correlation = "N10")
-as.tibble(sk_dak_2)
+as_tible(sk_dak_2)
 
 p <- ggplot(sk_dak_2, aes(x=Ppr, y=z.calc, group=Tpr, color=Tpr)) +
     geom_line() +
@@ -134,7 +134,7 @@ library(tibble)
 tpr_all <- getStandingKatzTpr(pprRange = "lp")
 ppr <- c(0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5) 
 sk_corr_all <- createTidyFromMatrix(ppr, tpr_all, correlation = "N10")
-as.tibble(sk_corr_all)
+as_tible(sk_corr_all)
 
 p <- ggplot(sk_corr_all, aes(x=Ppr, y=z.calc, group=Tpr, color=Tpr)) +
     geom_line() +
@@ -183,5 +183,5 @@ sk_corr_all %>%
                   position=position_dodge(0.5))
 
 ## ------------------------------------------------------------------------
-as.tibble(smry_tpr_ppr)
+as_tibble(smry_tpr_ppr)
 
