@@ -108,7 +108,7 @@ tpr2 <- c(1.05, 1.1, 1.2, 1.3)
 ppr2 <- c(0.5, 1.0, 1.5, 2, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0, 5.5, 6.0, 6.5) 
 
 sk_corr_2 <- createTidyFromMatrix(ppr2, tpr2, correlation = "DPR")
-as.tibble(sk_corr_2)
+as_tibble(sk_corr_2)
 
 p <- ggplot(sk_corr_2, aes(x=Ppr, y=z.calc, group=Tpr, color=Tpr)) +
     geom_line() +
@@ -139,7 +139,7 @@ tpr_all <- getStandingKatzTpr(pprRange = "lp")
 ppr <- c(0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5) 
 
 sk_corr_all <- createTidyFromMatrix(ppr, tpr_all, correlation = "DPR")
-as.tibble(sk_corr_all)
+as_tibble(sk_corr_all)
 
 p <- ggplot(sk_corr_all, aes(x=Ppr, y=z.calc, group=Tpr, color=Tpr)) +
     geom_line() +
@@ -188,5 +188,5 @@ sk_corr_all %>%
                   position=position_dodge(0.5))
 
 ## ------------------------------------------------------------------------
-as.tibble(smry_tpr_ppr)
+as_tibble(smry_tpr_ppr)
 
